@@ -21,9 +21,10 @@
 #include <qlabel.h>
 #include <qlayout.h>
 #include <qlineedit.h>
-#include <qpushbutton.h>
 
 #include <kapplication.h>
+#include <kpushbutton.h>
+#include <kstdguiitem.h>
 
 #include "Archive.h"
 #include "ArchiveInfoWidget.h"
@@ -59,7 +60,7 @@ ArchiveInfoWidget::ArchiveInfoWidget( QWidget* parent, const char* name )
     _size = new QLabel( "???", this );
     _size->setFixedHeight( _size->sizeHint().height() );
 
-    _apply = new QPushButton( i18n( "&Apply" ), this );
+    _apply = new KPushButton( KStdGuiItem::apply(), this );
     _apply->setFixedSize( 80, _apply->sizeHint().height() );
     _apply->setEnabled( FALSE );
 
