@@ -45,7 +45,7 @@ BackupProfileWidget::BackupProfileWidget( QWidget* parent, const char* name )
     _archiveName = new QLineEdit( one );
     _archiveName->setFixedHeight( _archiveName->sizeHint().height() );
 
-    QLabel* lbl2 = new QLabel( i18n( "Working directory:" ), one );
+    QLabel* lbl2 = new QLabel( i18n( "Working folder:" ), one );
     lbl2->setFixedSize( lbl2->sizeHint() );
 
     _workingDir = new QComboBox( FALSE, one );
