@@ -1,5 +1,6 @@
 // KDat - a tar-based DAT archiver
-// Copyright (C) 1998  Sean Vyain, svyain@mail.tds.net
+// Copyright (C) 1998-2000  Sean Vyain, svyain@mail.tds.net
+// Copyright (C) 2001-2002  Lawrence Widman, kdat@cardiothink.com
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -20,7 +21,7 @@
 
 #include <stdio.h>
 
-#include <qlist.h>
+#include <qptrlist.h>
 #include <qstring.h>
 
 #include "Range.h"
@@ -45,7 +46,7 @@ class File {
     } _union;
     QString     _name;
     File*       _parent;
-    QList<File> _children;
+    QPtrList<File> _children;
     RangeList   _ranges;
 public:
     /**
@@ -175,14 +176,14 @@ public:
      *
      * @return A list of the immediate children of this file entry.
      */
-    const QList<File>& getChildren();
+    const QPtrList<File>& getChildren();
 
     /**
      * Get the list of ranges of this file and all of its children.
      *
      * @return A list of ranges.
      */
-    const QList<Range>& getRanges();
+    const QPtrList<Range>& getRanges();
 
     /**
      * Add a new file entry as a child of this file entry.
