@@ -22,12 +22,12 @@
 #include <qlabel.h>
 #include <qlayout.h>
 #include <qlineedit.h>
+#include <kpushbutton.h>
+#include <kstdguiitem.h>
 
 #include <kapplication.h>
 #include <kglobal.h>
 #include <klocale.h>
-#include <kpushbutton.h>
-#include <kstdguiitem.h>
 
 #include "Options.h"
 #include "FormatOptDlg.h"
@@ -61,9 +61,9 @@ FormatOptDlg::FormatOptDlg( const QString & def, QWidget* parent, const char* na
     _tapeSizeUnits->insertItem( "MB" );
     _tapeSizeUnits->insertItem( "GB" );
 
-    QPushButton* ok     = new KPushButton( KStdGuiItem::ok(), this );
+    KPushButton* ok     = new KPushButton( KStdGuiItem::ok(), this );
     ok->setFixedSize( 80, ok->sizeHint().height() );
-    QPushButton* cancel = new KPushButton( KStdGuiItem::cancel(), this );
+    KPushButton* cancel = new KPushButton( KStdGuiItem::cancel(), this );
     cancel->setFixedSize( 80, cancel->sizeHint().height() );
 
     QVBoxLayout* l1 = new QVBoxLayout( this, 8, 4 );
@@ -127,7 +127,7 @@ void FormatOptDlg::okClicked()
         // GB
         _size *= 1024*1024;
     }
-
+    
     accept();
 }
 
