@@ -1,5 +1,6 @@
 // KDat - a tar-based DAT archiver
-// Copyright (C) 1998  Sean Vyain, svyain@mail.tds.net
+// Copyright (C) 1998-2000  Sean Vyain, svyain@mail.tds.net
+// Copyright (C) 2001-2002  Lawrence Widman, kdat@cardiothink.com
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -19,6 +20,9 @@
 #define _KDat_h_
 
 #include <kmainwindow.h>
+#include <kdialog.h>
+#include <qpushbutton.h>
+#include <qlabel.h>
 
 class KMenuBar;
 class QSplitter;
@@ -84,7 +88,18 @@ private:
                         bool incremental, const QString& snapshot, bool removeSnapshot );
 
     KDat();
-    
+   
+    // 2002-01-24 LEW
+    // used in calcBackupSize() to see whether user cancelled the on-going 
+    // backup to tape.  
+    KDialog*                 _backupdialog;
+    QPushButton*             _cancel;
+    QPushButton*             _continue;
+    QLabel*                  _lbl;
+    int                      stop_flag;  
+    void create_backup_dialog();
+    // 2002-01-24 LEW
+
 private slots:
     void localExpanding( KTreeViewItem* item, bool& allow );
     void localExpanded( int index );
@@ -110,7 +125,12 @@ private slots:
     void slotTapeDevice();
     void slotTapeMounted();
     void slotTapeUnmounted();
-    
+
+    // 2002-01-24 LEW    
+    void backupCancel();
+    void backupContinue();
+    // 2002-01-24 LEW
+
 protected:
     virtual void readProperties( KConfig* config );
     virtual void saveProperties( KConfig* config );
@@ -246,6 +266,7 @@ public:
      * @param files This list will become the selection.
      */
     void setBackupFiles( const QStringList& files );
+
 public slots:
     /**
      * Display a text message in the status bar.
@@ -258,6 +279,7 @@ public slots:
      * Initialize the KDat main window before displaying.
      */
     virtual void show();
+
 };
 
 #endif
