@@ -1,5 +1,6 @@
 // KDat - a tar-based DAT archiver
-// Copyright (C) 1998  Sean Vyain, svyain@mail.tds.net
+// Copyright (C) 1998-2000  Sean Vyain, svyain@mail.tds.net
+// Copyright (C) 2001-2002  Lawrence Widman, kdat@cardiothink.com
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -19,13 +20,14 @@
 #include <stdlib.h>
 #include <time.h>
 #include <unistd.h>
+#include <errno.h>
 
 #include <qfile.h>
-#include <qmessagebox.h>
 
+#include <kmessagebox.h>
 #include <klocale.h>
-#include <kstddirs.h>
-#include <kapp.h>
+#include <kstandarddirs.h>
+#include <kapplication.h>
 
 #include "IndexDlg.h"
 #include "KDat.h"
@@ -71,13 +73,13 @@ void Tape::format()
 {
     // Rewind tape.
     if ( !TapeDrive::instance()->rewind() ) {
-        QMessageBox::warning( KDat::getInstance(), i18n( "KDat: Format Failed" ), i18n( "Rewinding tape failed." ), i18n("OK"));
+        KMessageBox::error( KDat::getInstance(), i18n( "Rewinding tape failed." ), i18n("Format Failed"));
         return;
     }
 
     // Set block size for tape.
     if ( !TapeDrive::instance()->setBlockSize( Options::instance()->getTapeBlockSize() ) ) {
-        QMessageBox::information( KDat::getInstance(), i18n( "KDat: Format Failed" ), i18n( "Cannot set tape block size." ), i18n("OK") );
+        KMessageBox::error( KDat::getInstance(), i18n( "Cannot set tape block size." ), i18n("Format Failed"));
         return;
     }
 
@@ -86,25 +88,25 @@ void Tape::format()
 
     // KDat magic string.
     if ( TapeDrive::instance()->write( KDAT_MAGIC, KDAT_MAGIC_LENGTH ) < KDAT_MAGIC_LENGTH ) {
-        QMessageBox::information( KDat::getInstance(), i18n( "KDat: Format Failed" ), i18n( "Writing magic string failed." ), i18n("OK") );
+        KMessageBox::error( KDat::getInstance(), i18n( "Writing magic string failed." ), i18n("Format Failed"));
         return;
     }
-    
+
     // Tape header version number.
     iv = KDAT_TAPE_HEADER_VERSION;
     if ( TapeDrive::instance()->write( (const char*)&iv, 4 ) < 4 ) {
-        QMessageBox::warning( KDat::getInstance(), i18n( "KDat: Format Failed" ), i18n( "Writing version number failed." ), i18n("OK") );
+        KMessageBox::error( KDat::getInstance(), i18n( "Writing version number failed." ), i18n("Format Failed") );
         return;
     }
 
     // Write tape ID.  Tape ID is machine name + current time.
     iv = _id.length() + 1;
     if ( TapeDrive::instance()->write( (const char*)&iv, 4 ) < 4 ) {
-        QMessageBox::warning( KDat::getInstance(), i18n( "KDat: Format Failed" ), i18n( "Writing tape ID length failed." ), i18n("OK") );
+        KMessageBox::error( KDat::getInstance(), i18n( "Writing tape ID length failed." ), i18n("Format Failed") );
         return;
     }
     if ( TapeDrive::instance()->write( _id, iv ) < iv ) {
-        QMessageBox::warning( KDat::getInstance(), i18n( "KDat: Format Failed" ), i18n( "Writing tape ID failed." ), i18n("OK") );
+        KMessageBox::error( KDat::getInstance(), i18n( "Writing tape ID failed." ), i18n("Format Failed") );
         return;
     }
 
@@ -119,22 +121,43 @@ void Tape::format()
 void Tape::read()
 {
     if ( !_stubbed ) {
-        return;
+      /* 2002-01-28 LEW */
+      // printf("Can't read tape data because tape isn't stubbed\n" );
+      /* 2002-01-28 LEW */
+      return;
     }
 
     _stubbed = FALSE;
 
+    /* 2002-01-28 LEW */
+    // printf("Preparing to read tape data\n" );
+    // QString filename1 = locateLocal( "appdata", _id);
+    // printf("The tape data are in \"%s\"\n", filename1.ascii() );
+    /* 2002-01-28 LEW */
+
     if ( !_fptr ) {
         QString filename = locateLocal( "appdata", _id);
-    
         _fptr = fopen( QFile::encodeName(filename), "r" );
+
+	/* 2002-01-28 LEW */
+#ifdef DEBUG
+	//	printf("Opened tape archive file \"%s\". %s %d\n", 
+	//	       filename.ascii(), __FILE__, __LINE__ );
+#endif /* DEBUG */
+	/* 2002-01-28 LEW */
+
     }
 
     if ( !_fptr ) {
         // No tape index file was found.
-        if ( QMessageBox::information( KDat::getInstance(), i18n( "KDat: Tape Index" ), i18n( "No index file was found for this tape.\nRecreate the index from tape?" ), i18n("OK") ) == 0 ) {
+        int result = KMessageBox::warningContinueCancel( KDat::getInstance(), 
+                 i18n( "No index file was found for this tape.\n"
+                       "Recreate the index from tape?" ), 
+                 i18n("Tape Index"), 
+                 i18n("Recreate"));
+        if (result == KMessageBox::Continue ) {
             write();
-            
+
             IndexDlg dlg( this, KDat::getInstance() );
             dlg.exec();
             TapeManager::instance()->addTape( this );
@@ -143,15 +166,17 @@ void Tape::read()
             return;
         }
     }
-    
+
     char buf[4096];
 
     fseek( _fptr, 0, SEEK_SET );
 
     // Read index file version number.
     if ( !fgets( buf, 4096, _fptr ) ) {
-      QMessageBox::warning( KDat::getInstance(), i18n( "KDat: Index File Error" ), i18n( "Reading version number failed." ), i18n("OK") );
         fclose( _fptr );
+        KMessageBox::error( KDat::getInstance(), 
+                              i18n( "Reading version number failed." ), 
+                              i18n("Index File Error") );
         return;
     }
     int version = atoi( buf );
@@ -190,9 +215,9 @@ void Tape::read()
 
         default:
         {
-            QString msg;
-            msg = QString::fromUtf8(QCString().sprintf( i18n( "The tape index file format is version %d.  The index cannot be read by this version of KDat.  Perhaps the tape index file was created by a newer version of KDat?" ).utf8(), version ) );
-            QMessageBox::warning( KDat::getInstance(), i18n( "KDat: Index File Error" ), msg, i18n("OK") );
+            KMessageBox::sorry( KDat::getInstance(), 
+                i18n( "The tape index file format is version %d. The index cannot be read by this version of KDat. Perhaps the tape index file was created by a newer version of KDat?" ).arg(version ),
+                i18n("Tape Index") );
         }
     }
 }
@@ -201,7 +226,7 @@ void Tape::readAll( int version )
 {
     read();
 
-    QListIterator<Archive> i( _children );
+    QPtrListIterator<Archive> i( _children );
     for ( ; i.current(); ++i ) {
         i.current()->readAll( version );
     }
@@ -210,10 +235,24 @@ void Tape::readAll( int version )
 void Tape::write()
 {
     QString filename = locateLocal( "appdata", _id);
-    
+
+    /* 2002-01-28 LEW */
+#ifdef DEBUG
+    //    printf("Preparing to write the archive data to \"%s\". %s %d\n", 
+    //            filename.ascii(), __FILE__, __LINE__ );
+#endif /* DEBUG */
+    /* 2002-01-28 LEW */
+
     if ( !_fptr ) {
         _fptr = fopen( QFile::encodeName(filename), "w" );
 
+    /* 2002-01-31 LEW */
+#ifdef DEBUG
+	//  printf("Opened new archive file \"%s\". %s %d\n", 
+	//  filename.ascii(), __FILE__, __LINE__ );
+#endif /* DEBUG */
+    /* 2002-01-31 LEW */
+
         if ( !_fptr ) {
             // Suck!
             printf( "Tape::write() -- cannot open '%s' for writing!\n", filename.ascii() );
@@ -221,8 +260,14 @@ void Tape::write()
         }
     } else {
         freopen( QFile::encodeName(filename), "w", _fptr );
+    /* 2002-01-31 LEW */
+#ifdef DEBUG
+	//	printf("Reopened new archive file \"%s\". %s %d\n", 
+	//	       filename.ascii(), __FILE__, __LINE__ );
+#endif /* DEBUG */
+    /* 2002-01-31 LEW */
     }
-    
+
     int zero = 0;
 
     //===== Write the tape data =====
@@ -247,7 +292,7 @@ void Tape::write()
     }
 
     //===== Write archives =====
-    QListIterator<Archive> i( _children );
+    QPtrListIterator<Archive> i( _children );
     int count = 0;
     for ( ; i.current(); ++i, count++ ) {
         // Fill in the file offset.
@@ -279,14 +324,14 @@ QString Tape::getName()
 int Tape::getCTime()
 {
     read();
-    
+
     return _ctime;
 }
 
 int Tape::getMTime()
 {
     read();
-    
+
     return _mtime;
 }
 
@@ -297,7 +342,7 @@ int Tape::getSize()
     return _size;
 }
 
-const QList<Archive>& Tape::getChildren()
+const QPtrList<Archive>& Tape::getChildren()
 {
     read();
 
@@ -306,6 +351,10 @@ const QList<Archive>& Tape::getChildren()
 
 void Tape::setName( const QString & name )
 {
+    /* 2002-01-31 LEW */
+    int i;
+    /* 2002-01-31 LEW */
+
     read();
 
     if ( !_fptr ) {
@@ -313,18 +362,97 @@ void Tape::setName( const QString & name )
         write();
     }
 
+    // change file to read-write so we can update it   2002-01-31 LEW
+    QString filename = locateLocal( "appdata", _id);
+    freopen( QFile::encodeName(filename), "r+", _fptr );
+
     _name = name;
 
     char buf[4096];
-    fseek( _fptr, 0, SEEK_SET );
-    fgets( buf, 4096, _fptr );
-    fgets( buf, 4096, _fptr );
-    fseek( _fptr, 12, SEEK_CUR );
+    if( fseek( _fptr, 0, SEEK_SET ) < 0 )
+      {
+	clearerr( _fptr );
+#ifdef DEBUG    /* Can't create new i18n strings now, so we'll save this for KDE 3.1 */
+       	        /* Note to translator:  this error checking was added while tracking
+                   down a bug that turns out to be unrelated.  The errors I'm looking
+                   for here haven't happened in real use, so there is no rush to add
+                   these checks in KDE 3.0.  Thanks. - LW */
+	QString msg = i18n("Error during fseek #1 while accessing archive: \"");
+        msg.append( getID() );
+        msg.append( "\": " );
+	msg.append( i18n(strerror( errno )) );
+	printf("%s\n", msg.latin1());      
+	KMessageBox::error(NULL, msg, i18n("File Access Error"));
+#endif /* DEBUG */
+	return;      
+      }
+    if( fgets( buf, 4096, _fptr ) == NULL )
+      {
+	clearerr( _fptr );
+#ifdef DEBUG    /* Can't create new i18n strings now, so we'll save this for KDE 3.1 */
+	QString msg = i18n("Error while accessing string #1 in archive: \"");
+        msg.append( getID() );
+        msg.append( "\": " );
+	msg.append( i18n(strerror( errno )) );
+	printf("%s\n", msg.latin1());      
+	KMessageBox::error(NULL, msg, i18n("File Access Error"));
+#endif /* DEBUG */
+	return;      
+      }
+    if( fgets( buf, 4096, _fptr ) == NULL )
+      {
+	clearerr( _fptr );
+#ifdef DEBUG    /* Can't create new i18n strings now, so we'll save this for KDE 3.1 */
+	QString msg = i18n("Error while accessing string #2 in archive: \"");
+        msg.append( getID() );
+        msg.append( "\": " );
+	msg.append( i18n(strerror( errno )) );
+	printf("%s\n", msg.latin1());      
+	KMessageBox::error(NULL, msg, i18n("File Access Error"));
+#endif /* DEBUG */
+	return;      
+      }
+    if( fseek( _fptr, 12, SEEK_CUR ) < 0 )
+      {
+	clearerr( _fptr );
+#ifdef DEBUG    /* Can't create new i18n strings now, so we'll save this for KDE 3.1 */
+	QString msg = i18n("Error during fseek #2 while accessing archive: \"");
+        msg.append( getID() );
+        msg.append( "\": " );
+	msg.append( i18n(strerror( errno )) );
+	printf("%s\n", msg.latin1());      
+	KMessageBox::error(NULL, msg, i18n("File Access Error"));
+#endif /* DEBUG */
+	return;      
+      }
     memset( buf, 0, 4096 );
     memcpy( buf, _name.ascii(), _name.length() > 4095 ? 4095 : _name.length() );
-    fwrite( buf, sizeof( char ), 4096, _fptr );
+    i = fwrite( buf, sizeof( char ), 4096, _fptr );
+    /* 2002-01-31 LEW */
+    /* Note to translator: I know it's past the deadline, so don't translate this.  I think
+       I fixed the bug that caused this error to occur.  Thanks - LW */
+    if( ( i < 4096 ) || ( ferror( _fptr ) != 0 )){
+      clearerr( _fptr );
+      QString msg = i18n("Error while updating archive name: ");
+      msg.append( i18n(strerror( errno )) );
+      printf("%s\n", msg.latin1());      
+      KMessageBox::error(NULL, msg, i18n("File Access Error"));
+      // return;      
+    /* 2002-01-31 LEW */
+    }
     fflush( _fptr );
 
+    /* 2002-01-31 LEW */
+#ifdef DEBUG
+    //    printf("Tape::setName. wrote \"%s\" (%d bytes) into archive ID %s. %s %d\n", 
+    //	   _name.ascii(), _name.length(), getID().latin1(), __FILE__, __LINE__);
+    //    printf("  The buffer size is 4096.  %d bytes were written\n", i);
+#endif /* DEBUG */
+    /* 2002-01-31 LEW */
+
+    // change back to read-only   2002-01-31 LEW
+    freopen( QFile::encodeName(filename), "r", _fptr );
+
     TapeManager::instance()->tapeModified( this );
 }
 
@@ -337,6 +465,10 @@ void Tape::setMTime( int mtime )
         write();
     }
 
+    // change file to read-write so we can update it   2002-01-31 LEW
+    QString filename = locateLocal( "appdata", _id);
+    freopen( QFile::encodeName(filename), "r+", _fptr );
+
     _mtime = mtime;
 
     char buf[4096];
@@ -347,6 +479,9 @@ void Tape::setMTime( int mtime )
     fwrite( &_mtime, sizeof( _mtime ), 1, _fptr );
     fflush( _fptr );
 
+    // change back to read-only   2002-01-31 LEW
+    freopen( QFile::encodeName(filename), "r", _fptr );
+
     TapeManager::instance()->tapeModified( this );
 }
 
@@ -360,7 +495,11 @@ void Tape::setSize( int size )
     }
 
     _size = size;
-    
+
+    // change file to read-write so we can update it   2002-01-31 LEW
+    QString filename = locateLocal( "appdata", _id);
+    freopen( QFile::encodeName(filename), "r+", _fptr );
+
     char buf[4096];
     fseek( _fptr, 0, SEEK_SET );
     fgets( buf, 4096, _fptr );
@@ -369,13 +508,24 @@ void Tape::setSize( int size )
     fwrite( &_size, sizeof( _size ), 1, _fptr );
     fflush( _fptr );
 
+    // change back to read-only   2002-01-31 LEW
+    freopen( QFile::encodeName(filename), "r", _fptr );
+
     TapeManager::instance()->tapeModified( this );
 }
 
 void Tape::addChild( Archive* archive )
 {
+    /* 2002-01-28 LEW */
+    // printf("Preparing to add archive to tape file\n" );
+    /* 2002-01-28 LEW */
+
     read();
-    
+
+    // change file to read-write so we can update it   2002-01-31 LEW
+    QString filename = locateLocal( "appdata", _id);
+    freopen( QFile::encodeName(filename), "r+", _fptr );
+
     archive->calcRanges();
 
     _children.append( archive );
@@ -396,6 +546,13 @@ void Tape::addChild( Archive* archive )
     fflush( _fptr );
 
     setMTime( time( NULL ) );
+
+    // change back to read-only   2002-01-31 LEW
+    freopen( QFile::encodeName(filename), "r", _fptr );
+
+    /* 2002-01-28 LEW */
+    // printf("Done adding archive to tape file\n" );
+    /* 2002-01-28 LEW */
 }
 
 void Tape::removeChild( Archive* archive )
@@ -428,6 +585,9 @@ void Tape::removeChild( Archive* archive )
     freopen( QFile::encodeName(filename), "r+", _fptr );
     fflush( _fptr );
 
+    // change back to read-only   2002-01-31 LEW
+    freopen( QFile::encodeName(filename), "r", _fptr );
+
     setMTime( time( NULL ) );
 }
 
@@ -457,6 +617,9 @@ void Tape::clear()
     freopen( QFile::encodeName(filename), "r+", _fptr );
     fflush( _fptr );
 
+    // change back to read-only   2002-01-31 LEW
+    freopen( QFile::encodeName(filename), "r", _fptr );
+
     setMTime( time( NULL ) );
 }
 
@@ -468,33 +631,33 @@ void Tape::readVersion1Index( FILE* fptr )
 
     // Read the tapeID.
     if ( !fgets( buf, 4096, fptr ) ) {
-        QMessageBox::warning( KDat::getInstance(), i18n( "KDat: Index File Error" ), i18n( "Reading tape ID failed." ), i18n("OK") );
+        KMessageBox::error( KDat::getInstance(), i18n( "Reading tape ID failed." ), i18n("Index File Error") );
         return;
     }
     QCString tapeID = buf;
     tapeID.truncate( tapeID.length() - 1 );
     if ( tapeID !=_id ) {
-        QMessageBox::warning( KDat::getInstance(), i18n( "KDat: Index File Error" ), i18n( "Tape ID on tape does not match tape ID in index file." ), i18n("OK") );
+        KMessageBox::error( KDat::getInstance(), i18n( "Tape ID on tape does not match tape ID in index file." ), i18n("Index File Error") );
         return;
     }
 
     // Read creation time.
     if ( !fgets( buf, 4096, fptr ) ) {
-        QMessageBox::warning( KDat::getInstance(), i18n( "KDat: Index File Error" ), i18n( "Reading creation time failed." ), i18n("OK") );
+        KMessageBox::error( KDat::getInstance(), i18n( "Reading creation time failed." ), i18n("Index File Error") );
         return;
     }
     _ctime = atoi( buf );
 
     // Read modification time.
     if ( !fgets( buf, 4096, fptr ) ) {
-        QMessageBox::warning( KDat::getInstance(), i18n( "KDat: Index File Error" ), i18n( "Reading modification time failed." ), i18n("OK") );
+        KMessageBox::error( KDat::getInstance(), i18n( "Reading modification time failed." ), i18n("Index File Error") );
         return;
     }
     _mtime = atoi( buf );
 
     // Read tape name.
     if ( !fgets( buf, 4096, fptr ) ) {
-        QMessageBox::warning( KDat::getInstance(), i18n( "KDat: Index File Error" ), i18n( "Reading tape name failed." ), i18n("OK") );
+        KMessageBox::error( KDat::getInstance(), i18n( "Reading tape name failed." ), i18n("Index File Error") );
         return;
     }
     _name = buf;
@@ -502,14 +665,14 @@ void Tape::readVersion1Index( FILE* fptr )
 
     // Read tape size.
     if ( !fgets( buf, 4096, fptr ) ) {
-        QMessageBox::warning( KDat::getInstance(), i18n( "KDat: Index File Error" ), i18n( "Reading tape size failed." ), i18n("OK") );
+        KMessageBox::error( KDat::getInstance(), i18n( "Reading tape size failed." ), i18n("Index File Error") );
         return;
     }
     _size = atoi( buf );
 
     // Read number of archives.
     if ( !fgets( buf, 4096, fptr ) ) {
-        QMessageBox::warning( KDat::getInstance(), i18n( "KDat: Index File Error" ), i18n( "Reading archive count failed." ), i18n("OK") );
+        KMessageBox::error( KDat::getInstance(), i18n( "Reading archive count failed." ), i18n("Index File Error") );
         return;
     }
     int numArchives = atoi( buf );
@@ -517,7 +680,7 @@ void Tape::readVersion1Index( FILE* fptr )
     for ( ; numArchives; numArchives-- ) {
         // Read archive name.
         if ( !fgets( buf, 4096, fptr ) ) {
-            QMessageBox::warning( KDat::getInstance(), i18n( "KDat: Index File Error" ), i18n( "Reading archive name failed." ), i18n("OK") );
+            KMessageBox::error( KDat::getInstance(), i18n( "Reading archive name failed." ), i18n("Index File Error") );
             return;
         }
         QString archiveName = buf;
@@ -525,21 +688,21 @@ void Tape::readVersion1Index( FILE* fptr )
 
         // Read archive time stamp.
         if ( !fgets( buf, 4096, fptr ) ) {
-            QMessageBox::warning( KDat::getInstance(), i18n( "KDat: Index File Error" ), i18n( "Reading archive time stamp failed." ), i18n("OK") );
+            KMessageBox::error( KDat::getInstance(), i18n( "Reading archive time stamp failed." ), i18n("Index File Error") );
             return;
         }
         int archiveTimeStamp = atoi( buf );
 
         // Read archive start block.
         if ( !fgets( buf, 4096, fptr ) ) {
-            QMessageBox::warning( KDat::getInstance(), i18n( "KDat: Index File Error" ), i18n( "Reading archive start block failed." ), i18n("OK") );
+            KMessageBox::error( KDat::getInstance(), i18n( "Reading archive start block failed." ), i18n("Index File Error") );
             return;
         }
         int archiveStartBlock = atoi( buf );
 
         // Read archive end block.
         if ( !fgets( buf, 4096, fptr ) ) {
-            QMessageBox::warning( KDat::getInstance(), i18n( "KDat: Index File Error" ), i18n( "Reading archive end block failed." ), i18n("OK") );
+            KMessageBox::error( KDat::getInstance(), i18n( "Reading archive end block failed." ), i18n("Index File Error") );
             return;
         }
         int archiveEndBlock = atoi( buf );
@@ -547,12 +710,12 @@ void Tape::readVersion1Index( FILE* fptr )
         // Create the archive.
         Archive* archive = new Archive( this, archiveTimeStamp, archiveName );
         archive->setEndBlock( archiveEndBlock - archiveStartBlock );
-        
+
         _children.append( archive );
-        
+
         // Read the number of files.
         if ( !fgets( buf, 4096, fptr ) ) {
-            QMessageBox::warning( KDat::getInstance(), i18n( "KDat: Index File Error" ), i18n( "Reading archive file count failed." ), i18n("OK") );
+            KMessageBox::error( KDat::getInstance(), i18n( "Reading archive file count failed." ), i18n("Index File Error") );
             return;
         }
         int archiveNumFiles = atoi( buf );
@@ -564,29 +727,29 @@ void Tape::readVersion1Index( FILE* fptr )
         for ( ; archiveNumFiles; archiveNumFiles-- ) {
             // Read file name.
             if ( !fgets( buf, 4096, fptr ) ) {
-                QMessageBox::warning( KDat::getInstance(), i18n( "KDat: Index File Error" ), i18n( "Reading file name failed." ), i18n("OK") );
+                KMessageBox::error( KDat::getInstance(), i18n( "Reading file name failed." ), i18n("Index File Error") );
                 return;
             }
             QString fileName = buf;
             fileName.truncate( fileName.length() - 1 );
-            
+
             // Read file size.
             if ( !fgets( buf, 4096, fptr ) ) {
-                QMessageBox::warning( KDat::getInstance(), i18n( "KDat: Index File Error" ), i18n( "Reading file size failed." ), i18n("OK") );
+                KMessageBox::error( KDat::getInstance(), i18n( "Reading file size failed." ), i18n("Index File Error") );
                 return;
             }
             int fileSize = atoi( buf );
-            
+
             // Read file modification time.
             if ( !fgets( buf, 4096, fptr ) ) {
-                QMessageBox::warning( KDat::getInstance(), i18n( "KDat: Index File Error" ), i18n( "Reading file modification time failed." ), i18n("OK") );
+                KMessageBox::error( KDat::getInstance(), i18n( "Reading file modification time failed." ), i18n("Index File Error") );
                 return;
             }
             int fileModTime = atoi( buf );
-            
+
             // Read file record number.
             if ( !fgets( buf, 4096, fptr ) ) {
-                QMessageBox::warning( KDat::getInstance(), i18n( "KDat: Index File Error" ), i18n( "Reading file record number failed." ), i18n("OK") );
+                KMessageBox::error( KDat::getInstance(), i18n( "Reading file record number failed." ), i18n("Index File Error") );
                 return;
             }
             int fileRecord = atoi( buf );
@@ -615,48 +778,48 @@ void Tape::readVersion2Index( FILE* fptr )
 
     // Read the tapeID.
     if ( !fgets( buf, 4096, fptr ) ) {
-        QMessageBox::warning( KDat::getInstance(), i18n( "KDat: Index File Error" ), i18n( "Reading tape ID failed." ), i18n("OK") );
+        KMessageBox::error( KDat::getInstance(), i18n( "Reading tape ID failed." ), i18n("Index File Error") );
         return;
     }
     QCString tapeID = buf;
     tapeID.truncate( tapeID.length() - 1 );
     if ( tapeID != _id ) {
-        QMessageBox::warning( KDat::getInstance(), i18n( "KDat: Index File Error" ), i18n( "Tape ID on tape does not match tape ID in index file." ), i18n("OK") );
+        KMessageBox::error( KDat::getInstance(), i18n( "Tape ID on tape does not match tape ID in index file." ), i18n("Index File Error") );
         return;
     }
-    
+
     // Read creation time.
     if ( !fgets( buf, 4096, fptr ) ) {
-        QMessageBox::warning( KDat::getInstance(), i18n( "KDat: Index File Error" ), i18n( "Reading creation time failed." ), i18n("OK") );
+        KMessageBox::error( KDat::getInstance(), i18n( "Reading creation time failed." ), i18n("Index File Error") );
         return;
     }
     _ctime = atoi( buf );
-    
+
     // Read modification time.
     if ( !fgets( buf, 4096, fptr ) ) {
-        QMessageBox::warning( KDat::getInstance(), i18n( "KDat: Index File Error" ), i18n( "Reading modification time failed." ), i18n("OK") );
+        KMessageBox::error( KDat::getInstance(), i18n( "Reading modification time failed." ), i18n("Index File Error") );
         return;
     }
     _mtime = atoi( buf );
-    
+
     // Read tape name.
     if ( !fgets( buf, 4096, fptr ) ) {
-        QMessageBox::warning( KDat::getInstance(), i18n( "KDat: Index File Error" ), i18n( "Reading tape name failed." ), i18n("OK") );
+        KMessageBox::error( KDat::getInstance(), i18n( "Reading tape name failed." ), i18n("Index File Error") );
         return;
     }
     _name = buf;
     _name.truncate( _name.length() - 1 );
-    
+
     // Read tape size.
     if ( !fgets( buf, 4096, fptr ) ) {
-        QMessageBox::warning( KDat::getInstance(), i18n( "KDat: Index File Error" ), i18n( "Reading tape size failed." ), i18n("OK") );
+        KMessageBox::error( KDat::getInstance(), i18n( "Reading tape size failed." ), i18n("Index File Error") );
         return;
     }
     _size = atoi( buf );
-    
+
     // Read number of archives.
     if ( !fgets( buf, 4096, fptr ) ) {
-        QMessageBox::warning( KDat::getInstance(), i18n( "KDat: Index File Error" ), i18n( "Reading archive count failed." ), i18n("OK") );
+        KMessageBox::error( KDat::getInstance(), i18n( "Reading archive count failed." ), i18n("Index File Error") );
         return;
     }
     int numArchives = atoi( buf );
@@ -677,25 +840,25 @@ void Tape::readVersion3Index( FILE* fptr )
 
     // Read the tapeID.
     if ( !fgets( buf, 4096, fptr ) ) {
-        QMessageBox::warning( KDat::getInstance(), i18n( "KDat: Index File Error" ), i18n( "Reading tape ID failed." ), i18n("OK") );
+        KMessageBox::error( KDat::getInstance(), i18n( "Reading tape ID failed." ), i18n("Index File Error") );
         return;
     }
     QCString tapeID = buf;
     tapeID.truncate( tapeID.length() - 1 );
     if ( tapeID != _id ) {
-        QMessageBox::warning( KDat::getInstance(), i18n( "KDat: Index File Error" ), i18n( "Tape ID on tape does not match tape ID in index file." ), i18n("OK") );
+        KMessageBox::error( KDat::getInstance(), i18n( "Tape ID on tape does not match tape ID in index file." ), i18n("Index File Error") );
         return;
     }
-    
+
     // Read creation time.
     fread( &_ctime, sizeof( _ctime ), 1, fptr );
-    
+
     // Read modification time.
     fread( &_mtime, sizeof( _mtime ), 1, fptr );
 
     // Read tape size.
     fread( &_size, sizeof( _size ), 1, fptr );
-    
+
     // Read tape name.
     fread( buf, sizeof( char ), 4096, fptr );
     _name = buf;
@@ -720,29 +883,29 @@ void Tape::readVersion4Index( FILE* fptr )
 
     // Read the tapeID.
     if ( !fgets( buf, 4096, fptr ) ) {
-        QMessageBox::warning( KDat::getInstance(), i18n( "KDat: Index File Error" ), i18n( "Reading tape ID failed." ), i18n("OK") );
+        KMessageBox::error( KDat::getInstance(), i18n( "Reading tape ID failed." ), i18n("Index File Error") );
         return;
     }
     QCString tapeID = buf;
     tapeID.truncate( tapeID.length() - 1 );
     if ( tapeID != _id ) {
-        QMessageBox::warning( KDat::getInstance(), i18n( "KDat: Index File Error" ), i18n( "Tape ID on tape does not match tape ID in index file." ), i18n("OK") );
+        KMessageBox::error( KDat::getInstance(), i18n( "Tape ID on tape does not match tape ID in index file." ), i18n("Index File Error") );
         return;
     }
-    
+
     // Read creation time.
     fread( &_ctime, sizeof( _ctime ), 1, fptr );
-    
+
     // Read modification time.
     fread( &_mtime, sizeof( _mtime ), 1, fptr );
 
     // Read tape size.
     fread( &_size, sizeof( _size ), 1, fptr );
-    
+
     // Read tape name.
     fread( buf, sizeof( char ), 4096, fptr );
     _name = buf;
-    
+
     // Read number of archives.
     int numArchives;
     fread( &numArchives, sizeof( numArchives ), 1, fptr );
@@ -752,11 +915,18 @@ void Tape::readVersion4Index( FILE* fptr )
         fread( &ival, sizeof( ival ), 1, fptr );
         _children.append( new Archive( this, fptr, ival ) );
     }
+
+    /* 2002-01-31 LEW */
+#ifdef DEBUG
+    printf("Read contents of archive file \"%s\". %s %d\n", 
+	   _name.latin1(), __FILE__, __LINE__ );
+#endif /* DEBUG */
+    /* 2002-01-31 LEW */
 }
 
 void Tape::calcRanges()
 {
-    QListIterator<Archive> it( getChildren() );
+    QPtrListIterator<Archive> it( getChildren() );
     for ( ; it.current(); ++it ) {
         it.current()->calcRanges();
     }
