@@ -23,11 +23,12 @@
 #include <qlabel.h>
 #include <qlayout.h>
 #include <qlineedit.h>
-#include <qpushbutton.h>
 
 #include <kapplication.h>
 #include <kglobal.h>
 #include <klocale.h>
+#include <kpushbutton.h>
+#include <kstdguiitem.h>
 
 #include "Options.h"
 #include "Tape.h"
@@ -90,7 +91,7 @@ TapeInfoWidget::TapeInfoWidget( QWidget* parent, const char* name )
     _spaceUsed = new QLabel( "???", this );
     _spaceUsed->setFixedHeight( _spaceUsed->sizeHint().height() );
 
-    _apply = new QPushButton( i18n( "&Apply" ), this );
+    _apply = new KPushButton( KStdGuiItem::apply(), this );
     _apply->setFixedSize( 80, _apply->sizeHint().height() );
     _apply->setEnabled( FALSE );
 
