@@ -1,9 +1,32 @@
-//////////////////////////////////////////////////////////////
-//      $Id: fbsdInterface.cpp,v 1.36.2.1 2003/06/12 19:25:34 fawcett Exp $
-//
-// Author: Alex Hayward
-// xelah@ferret.lmh.ox.ac.uk
-//
+/* fbsdInterface.cc
+**
+** Copyright (C) 2000 by Alex Hayward <xelah@xelah.com>
+**
+*/
+
+
+/*
+** This program is free software; you can redistribute it and/or modify
+** it under the terms of the GNU General Public License as published by
+** the Free Software Foundation; either version 2 of the License, or
+** (at your option) any later version.
+**
+** This program is distributed in the hope that it will be useful,
+** but WITHOUT ANY WARRANTY; without even the implied warranty of
+** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+** GNU General Public License for more details.
+**
+** You should have received a copy of the GNU General Public License
+** along with this program in a file called COPYING; if not, write to
+** the Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
+** MA 02111-1307, USA.
+*/
+
+/*
+** Bug reports and questions can be sent to kde-devel@kde.org
+*/
+
+
 
 #include <errno.h>
 #include <stdlib.h>
@@ -13,9 +36,12 @@
 #include <unistd.h>
 #include <fcntl.h>
 
+#include <qstringlist.h>
+
 #include <klocale.h>
 #include <kglobal.h>
 #include <kiconloader.h>
+#include <kdebug.h>
 
 #include "fbsdInterface.h"
 #include "kpackage.h"
@@ -43,9 +69,9 @@ fbsdInterface::fbsdInterface():pkgInterface() {
 
   locatedialog = new Locations(i18n("Location of BSD Packages and Ports"));
   locatedialog->dLocations(1, 1, this, i18n("Ports"), "Pkg", "*.tgz",
-                           i18n("Location of Ports Tree (eg /usr/ports or /usr/opt)"),FALSE);
+                           i18n("Location of Ports Tree (e.g. /usr/ports or /usr/opt)"),FALSE);
   locatedialog->dLocations(1, 6, this, i18n("Packages"), "Pkg", "*.tgz",
-                           i18n("Location of Directories Containing BSD Packages or Package Trees"));
+                           i18n("Location of Folders Containing BSD Packages or Package Trees"));
   connect(locatedialog, SIGNAL(returnVal(LcacheObj *)), this, SLOT(setAvail(LcacheObj *)));
   locatedialog->apply_slot();
 
@@ -73,11 +99,28 @@ bool fbsdInterface::isType(char *, const QString &fname) {
   return false;
 }
 
+static void insertGroups(QDict<QString> *a, const char *cats)
+{
+  /* Create the list of groups (which is space-separated), and then
+  ** iterate through it with the iterator i. count is just to 
+  ** distinguish the first entry (count==0) from the rest, since
+  ** the key used in a->insert() needs to be different.
+  */
+  QStringList grlist = QStringList::split(' ',QString(cats));
+  unsigned int count = 0;
+  for (QStringList::Iterator i = grlist.begin(); 
+    i != grlist.end(); ++count,++i) {
+    a->insert( (count ? "also in" : "group"), new QString(*i));
+  }
+}
+
 packageInfo *fbsdInterface::getPackageInfo(char mode, const QString &pname, const QString &version) {
   QString name( pname);
   bool installed = false;
   kpackage->setStatus(i18n("Getting package info"));
 
+  kdDebug() << "Looking at package " << pname << endl;
+
   if (mode == 'i' && !version.isEmpty()) {
     name += "-" + version;
   }
@@ -96,7 +139,7 @@ packageInfo *fbsdInterface::getPackageInfo(char mode, const QString &pname, cons
       a->insert("base", new QString(name.left(last_dir + 1)) );
     } else {
       a->insert("filename", new QString(name));
-      a->insert("base", new QString(""));
+      a->insert("base", new QString());
     }
 
     // Look for a line of the form '@name <pkgname>'
@@ -156,12 +199,7 @@ packageInfo *fbsdInterface::getPackageInfo(char mode, const QString &pname, cons
       installed = inditem->installed;
       a->insert("maintainer", new QString(inditem->maint));
 
-      const char *space = strchr(inditem->cats, ' ');
-      if (space) {
-        a->insert("group", new QString(QString(inditem->cats).left(space - inditem->cats)));
-	a->insert("also in", new QString(space+1));
-      } else
-	a->insert("group", new QString(inditem->cats));
+      insertGroups(a,inditem->cats);
 
       a->insert("run depends", new QString(inditem->rdeps[0]? QString(inditem->rdeps) : i18n("none")));
       a->insert("build depends", new QString(inditem->bdeps[0]? QString(inditem->bdeps) : i18n("none")));
@@ -171,7 +209,7 @@ packageInfo *fbsdInterface::getPackageInfo(char mode, const QString &pname, cons
     a->insert("description", desc);
     free(buf);
   } else {
-    kpackage->setStatus("");
+    kpackage->setStatus(QString::null);
     return 0;
   }
 
@@ -179,11 +217,24 @@ packageInfo *fbsdInterface::getPackageInfo(char mode, const QString &pname, cons
   ret->packageState = installed? packageInfo::INSTALLED : packageInfo::AVAILABLE;
   ret->fixup();
   if (!installed) ret->smerge(typeID);
-  kpackage->setStatus("");
+  kpackage->setStatus(QString::null);
   return ret;
 }
 
-  QStringList fbsdInterface::getFileList(packageInfo *p) {
+QStringList fbsdInterface::getChangeLog(packageInfo *) {
+  return 0;
+}
+
+
+bool fbsdInterface::filesTab(packageInfo *) {
+  return TRUE;
+}
+
+bool fbsdInterface::changeTab(packageInfo *) {
+    return FALSE;
+}
+
+QStringList fbsdInterface::getFileList(packageInfo *p) {
 
   // Run pkg_info on the package name to get the file list.
   // The file list is returned on stdout, one per line.
@@ -202,7 +253,7 @@ packageInfo *fbsdInterface::getPackageInfo(char mode, const QString &pname, cons
   } else {
     if (!p->hasProperty("name")) {
       ret.append(i18n("Can't find package name!"));
-      kpackage->setStatus("");
+      kpackage->setStatus(QString::null);
       return ret;
     }
 
@@ -223,7 +274,7 @@ packageInfo *fbsdInterface::getPackageInfo(char mode, const QString &pname, cons
     const char *op = reader.buf.ascii();
     if (op == 0) {
       ret.append(i18n("pkg_info returned no output"));
-      kpackage->setStatus("");
+      kpackage->setStatus(QString::null);
       return ret;
     }
     char *buf = strdup(op);
@@ -237,7 +288,7 @@ packageInfo *fbsdInterface::getPackageInfo(char mode, const QString &pname, cons
     ret.append(i18n("Can't start pkg_info"));
   }
 
-  kpackage->setStatus("");
+  kpackage->setStatus(QString::null);
   return ret;
 }
 
@@ -282,7 +333,7 @@ QString fbsdInterface::uninstall(int uninstallFlags, packageInfo *p, bool &test)
 
 QString fbsdInterface::uninstall(int uninstallFlags, QPtrList<packageInfo> *p, bool &test)
 {
-  QString packs = "";
+  QString packs ;
   packageInfo *i;
 
   for (i = p->first(); i!= 0; i = p->next())  {
@@ -315,7 +366,7 @@ void fbsdInterface::addNV(QDict<QString> *d, const QString &name) {
 
   if (!parseName(name, n, v)) {
     *n = name;
-    *v = "";
+    *v = QString::null;
   }
 
   d->insert("name", n);
@@ -328,6 +379,8 @@ void fbsdInterface::setLocation() {
 }
 
 void fbsdInterface::setAvail(LcacheObj *slist) {
+  kdDebug() << k_funcinfo << endl;
+  
   if (packageLoc) delete packageLoc;
   packageLoc = slist;
 
@@ -357,12 +410,16 @@ void fbsdInterface::setAvail(LcacheObj *slist) {
 void fbsdInterface::listPackages(QPtrList<packageInfo> *pki) {
   int listscan;
 
+  kdDebug() << k_funcinfo << endl;
+  
   listInstalledPackages(pki);
+  
+  unsigned int hashcount = 0;
   for (listscan = 0; listscan < 256; listscan++) {
     bsdPortsIndexItem *scan = bsdPortsIndexItem::lists[listscan];
-
+    if (scan) hashcount++;
     while (scan != 0) {
-      if (!scan->installed && scan->bin) {
+      if (!scan->installed  /*&& scan->bin */) {
 	QDict<QString> *a = new QDict<QString>;
 	a->setAutoDelete(TRUE);
 
@@ -370,11 +427,7 @@ void fbsdInterface::listPackages(QPtrList<packageInfo> *pki) {
 	a->insert("summary", new QString(scan->name));
 	a->insert("maintainer", new QString(scan->maint));
 
-	const char *space = strchr(scan->cats, ' ');
-	if (space) {
-          a->insert("group", new QString(QString(scan->cats).left(space - scan->cats)));
-	  a->insert("also in", new QString(space+1));
-	} else a->insert("group", new QString(scan->cats));
+	insertGroups(a,scan->cats);
 
         a->insert("run depends", new QString(scan->rdeps[0]? QString(scan->rdeps) : i18n("none")));
         a->insert("build depends", new QString(scan->bdeps[0]? QString(scan->bdeps) : i18n("none")));
@@ -394,9 +447,14 @@ void fbsdInterface::listPackages(QPtrList<packageInfo> *pki) {
       scan = scan->next;
     }
   }
+  
+  kdDebug() << "There were " << hashcount << " occupied buckets." << endl;
+  kdDebug() << "There are " << pki->count() << " total ports." << endl;
 }
 
 void fbsdInterface::listInstalledPackages(QPtrList<packageInfo> *pki) {
+  kdDebug() << k_funcinfo << endl;
+  
 #define INFO_SEPARATOR "f;g#z-@IqbX%"
 
   // Open a pipe to a pkg_info process in order to read the comment, name
@@ -407,11 +465,11 @@ void fbsdInterface::listInstalledPackages(QPtrList<packageInfo> *pki) {
   reader.setup(PKG_INFO_BIN);
   *reader.proc << "-acdl" << INFO_SEPARATOR;
   if (!reader.start(0, FALSE)) {
-    kpackage->setStatus("");
+    kpackage->setStatus(QString::null);
     return;
   } else {
     if (reader.buf.isEmpty()) {
-      kpackage->setStatus("");
+      kpackage->setStatus(QString::null);
       return;
     }
     // We should now get:
@@ -436,7 +494,7 @@ void fbsdInterface::listInstalledPackages(QPtrList<packageInfo> *pki) {
 
       if (memcmp(line, INFO_SEPARATOR, sizeof(INFO_SEPARATOR)-1)) {
 	KpMsgE(i18n("Unexpected output from pkg_info: %1").arg(line), TRUE);
-        kpackage->setStatus("");
+        kpackage->setStatus(QString::null);
 	return;
       }
 
@@ -445,7 +503,7 @@ void fbsdInterface::listInstalledPackages(QPtrList<packageInfo> *pki) {
       int lastword_len = lastword? strlen(lastword) : 0;
       if (lastword_len < 2 || lastword[lastword_len-1] != ':') {
 	KpMsgE(i18n("Unexpected output from pkg_info (looking for package name): %1").arg(line), TRUE);
-        kpackage->setStatus("");
+        kpackage->setStatus(QString::null);
 	return;
       }
 
@@ -462,7 +520,7 @@ void fbsdInterface::listInstalledPackages(QPtrList<packageInfo> *pki) {
 	line = strtok(0, "\n");
 	if (line == 0) {
 	  KpMsgE(i18n("Unexpected EOF from pkg_info (looking for comment line)"), TRUE);
-          kpackage->setStatus("");
+          kpackage->setStatus(QString::null);
 	  return;
 	}
       } while (!done);
@@ -475,7 +533,7 @@ void fbsdInterface::listInstalledPackages(QPtrList<packageInfo> *pki) {
 	line = strtok(0, "\n");
 	if (line == 0) {
 	  KpMsgE(i18n("Unexpected EOF from pkg_info (looking for comment line)"), TRUE);
-          kpackage->setStatus("");
+          kpackage->setStatus(QString::null);
 	  return;
 	}
       } while (memcmp(line, INFO_SEPARATOR, sizeof(INFO_SEPARATOR)-1));
@@ -504,11 +562,11 @@ void fbsdInterface::listInstalledPackages(QPtrList<packageInfo> *pki) {
 
 	a->insert("maintainer", new QString(inditem->maint));
 
-	const char *space = strchr(inditem->cats, ' ');
-	if (space) {
-          a->insert("group", new QString(QString(inditem->cats).left(space - inditem->cats)));
-	  a->insert("also in", new QString(space+1));
-	} else a->insert("group", new QString(inditem->cats));
+	insertGroups(a,inditem->cats);
+	if (!a->find("group"))
+	{
+          kdDebug() << "Line <" << buf << "> has no group?" << endl;
+        }
 
         a->insert("run depends", new QString(inditem->rdeps[0]? QString(inditem->rdeps) : i18n("none")));
         a->insert("build depends", new QString(inditem->bdeps[0]? QString(inditem->bdeps) : i18n("none")));
@@ -517,8 +575,45 @@ void fbsdInterface::listInstalledPackages(QPtrList<packageInfo> *pki) {
 
       a->insert("description", desc);
 
+      int pkg_state = packageInfo::INSTALLED;
+      if (!a->find("group"))
+      {
+        QString s,*ps;
+        ps = a->find("name");
+        if (ps) s = *ps;
+        else s = "<anonymous>";
+
+        ps = a->find("version");
+        if (ps) s.append(QString("-")+(*ps));
+
+        kdDebug() << "Package " << (s) << " has no group." << endl;
+ 
+        /* This must be an installed package with no INDEX entry,
+        ** which usually means that the port has been updated.
+        */
+        reader.setup(PKG_INFO_BIN);
+        *reader.proc << "-o" << (s);
+        if (reader.start(QString::null,FALSE) && !reader.buf.isEmpty())
+        {
+          QStringList lines = QStringList::split('\n',reader.buf);
+          QString originName;
+          int originOffset = lines.findIndex(QString("Origin:"));
+          if (originOffset>=0) originName=lines[originOffset+1];
+          int slashOffset = -1;
+          if(!originName.isEmpty()) slashOffset=originName.find('/');
+          if(slashOffset>=0) originName.truncate(slashOffset);
+          if(!originName.isEmpty()) a->insert("group",new QString(originName));
+          pkg_state = packageInfo::UPDATED;
+        }
+        else
+        {
+          kdDebug() << "Could not read package origin info." << endl;
+        }
+      }
+
       packageInfo *info = new packageInfo(a, this);
-      info->packageState = packageInfo::INSTALLED;
+      info->packageState = pkg_state;
+
       info->fixup();
       //pki->append(info);
       info->pkgInsert(pki, typeID, true);
