@@ -44,7 +44,7 @@ FindF::FindF(QWidget *parent)
     : KDialogBase(parent, "find_file", false,
 		i18n("Find File"),
 		User1 | Close, User1, true,
-		i18n("&Find"))
+		KGuiItem(i18n("&Find"),"filefind"))
 {
     QFrame *page = makeMainWidget();
 
@@ -100,7 +100,7 @@ void FindF::doFind(const QString &str)
   QString t;
   int i, cnt = 0;
 
-  QApplication::setOverrideCursor( waitCursor ); 
+  QApplication::setOverrideCursor( waitCursor );
 
   tab->clear();
 
@@ -120,7 +120,7 @@ void FindF::doFind(const QString &str)
 	  int t1 = (*it).find('\t');
 	  QString s1 = (*it).left(t1);
 	  QString s2 = (*it).right((*it).length()-t1);
-	  s2 = s2.stripWhiteSpace(); 
+	  s2 = s2.stripWhiteSpace();
 
 	  new QListViewItem(tab, t, s1, s2);
 	}
@@ -132,7 +132,7 @@ void FindF::doFind(const QString &str)
     new QListViewItem(tab, "", i18n("--Nothing found--"));
   }
 
-  QApplication::restoreOverrideCursor(); 
+  QApplication::restoreOverrideCursor();
 }
 
 void FindF::done_slot()
@@ -148,7 +148,7 @@ void FindF::search(QListViewItem *item)
   int p;
 
   QString s = item->text(1);
-  s = s.stripWhiteSpace(); 
+  s = s.stripWhiteSpace();
   kdDebug() << "searchF=" << s << "\n";
 
   p = s.find(',');
