@@ -1,6 +1,32 @@
+/* kio.cpp
+**
+** Copyright (C) 1999,2000 Toivo Pedaste <toivo@ucs.uwa.edu.au>
+**
+*/
+
+/*
+** This program is free software; you can redistribute it and/or modify
+** it under the terms of the GNU General Public License as published by
+** the Free Software Foundation; either version 2 of the License, or
+** (at your option) any later version.
+**
+** This program is distributed in the hope that it will be useful,
+** but WITHOUT ANY WARRANTY; without even the implied warranty of
+** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+** GNU General Public License for more details.
+**
+** You should have received a copy of the GNU General Public License
+** along with this program in a file called COPYING; if not, write to
+** the Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
+** MA 02111-1307, USA.
+*/
+
+/*
+** Bug reports and questions can be sent to kde-devel@kde.org
+*/
+
 #include <kapplication.h>
 #include <kdebug.h>
-#include <kdebugclasses.h>
 #include "kio.h"
 
 Kio::Kio()
@@ -37,7 +63,7 @@ Kiod::~Kiod()
     delete fileT;
 }
 
-bool Kiod::listDir(QString url, QString fname, bool subdirs)
+bool Kiod::listDir(const QString &url, const QString &fname, bool subdirs)
 {
     delete file;
   file = new QFile(fname);
@@ -76,7 +102,7 @@ void Kiod::slotListEntries( KIO::Job *job, const KIO::UDSEntryList& entries )
   KIO::UDSEntryList::ConstIterator entryIt = entries.begin();
 
   for (; entryIt != entries.end(); ++entryIt) {
-      kdDebug() << "listDir " << dynamic_cast<KIO::ListJob*>(job)->url() << endl;
+      //kdDebug() << "listDir " << dynamic_cast<KIO::ListJob*>(job)->url() << endl;
       for (KIO::UDSEntry::ConstIterator it = (*entryIt).begin();
 	   it != (*entryIt).end(); it++ )
       {
@@ -92,7 +118,7 @@ void Kiod::slotListEntries( KIO::Job *job, const KIO::UDSEntryList& entries )
 
 void Kiod::slotFinished( KIO::Job *job )
 {
-    kdDebug() << "finished" << " " << job << " " << dynamic_cast<KIO::ListJob*>(job)->url() << endl;
+    //kdDebug() << "finished" << " " << job << " " << dynamic_cast<KIO::ListJob*>(job)->url() << endl;
     worked = (job->error() == 0);
     kapp->exit_loop();
 }
