@@ -44,7 +44,6 @@
 #include <kapplication.h>
 #include <kaccel.h>
 #include <kaction.h>
-#include <kkeydialog.h>
 #include <klocale.h>
 #include <kinputdialog.h>
 #include <kglobal.h>
@@ -170,9 +169,9 @@ void KPKG::setupMenu()
 
   KStdAction::saveOptions( this, SLOT(saveSettings()), actionCollection());
 
-  KStdAction::keyBindings( this, SLOT(setKeys()), actionCollection());
+  KStdAction::keyBindings( guiFactory(), SLOT(configureShortcuts()), actionCollection());
 
-  (void) (new KAction( i18n("Configure &Kpackage..."), "configure",
+  (void) (new KAction( i18n("Configure &KPackage..."), "configure",
 		       0, this,
 		       SLOT(setOptions()), actionCollection(), "kpack_options"));
 
@@ -269,10 +268,6 @@ void KPKG::setOptions(){
   optiondialog->restore();
 }
 
-void KPKG::setKeys(){
-  KKeyDialog::configure(actionCollection());
-}
-
 void KPKG::saveSettings(){
   writeSettings();
 }
