@@ -1,42 +1,51 @@
-//////////////////////////////////////////////////////////////////////////
-// $Id: kpackage.h,v 1.37.2.1 2003/03/13 00:05:21 rnolden Exp $	
-// File  : kpackage.h
-// Author: Toivo Pedaste
-//
-// This is the main widget for kpackage
-// The whole widget is a DND drop zone where users can drop packages to 
-// be installed.
-//
-//////////////////////////////////////////////////////////////////////////
+/* kpackage.h
+**
+** Copyright (C) 1999,2000 Toivo Pedaste <toivo@ucs.uwa.edu.au>
+**
+** This is the main widget for kpackage
+** The whole widget is a DND drop zone where users can drop packages to
+** be installed.
+*/
+
+/*
+** This program is free software; you can redistribute it and/or modify
+** it under the terms of the GNU General Public License as published by
+** the Free Software Foundation; either version 2 of the License, or
+** (at your option) any later version.
+**
+** This program is distributed in the hope that it will be useful,
+** but WITHOUT ANY WARRANTY; without even the implied warranty of
+** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+** GNU General Public License for more details.
+**
+** You should have received a copy of the GNU General Public License
+** along with this program in a file called COPYING; if not, write to
+** the Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
+** MA 02111-1307, USA.
+*/
+
+/*
+** Bug reports and questions can be sent to kde-devel@kde.org
+*/
+
+
+
 
 #ifndef KPACKAGE_H
 #define KPACKAGE_H
 
 #include "../config.h"
 
-// Standard Headers
-#include <stdio.h>
-
-// Qt Headers
-#include <qdir.h>
-#include <qwidget.h>
-#include <qframe.h>
-#include <qlabel.h>
-#include <qfiledialog.h> 
-#include <qgroupbox.h> 
-
 // KDE headers
-#include <kapplication.h>
-#include <kdebug.h>
-#include <kconfig.h>
 #include <kurl.h>
-#include <kprogress.h>
-#include <kmenubar.h>
-#include <kmainwindow.h> 
-#include <kfiledialog.h> 
-#include <kaction.h>
+#include <kmainwindow.h>
 #include <kpPty.h>
 
+class KFileDialog;
+class KProgress;
+class QFrame;
+class KConfig;
+class QLabel;
 class Search;
 class FindF;
 class Options;
@@ -48,7 +57,7 @@ class KRecentFilesAction;
 class KAction;
 class kpRun;
 
-#define kpinterfaceN 6
+#define kpinterfaceN 7
 
 //////////////////////////////////////////////////////////////////////////////
 //////////////////////////////////////////////////////////////////////////////
@@ -64,11 +73,11 @@ public:
   ~KPACKAGE();
   // Destructor
 
-    enum { OPEN_READWRITE 	= 1, 
-	   OPEN_READONLY 	= 2, 
+    enum { OPEN_READWRITE 	= 1,
+	   OPEN_READONLY 	= 2,
 	   OPEN_INSERT 		= 4 };
 
-  void setStatus(QString s);
+  void setStatus(const QString &s);
   // this sets the status bar's string to s
 
   void setPercent(int x);
@@ -82,7 +91,7 @@ public:
 
   void setup();
 
-  pkgInterface *pkType(QString fname);
+  pkgInterface *pkType(const QString &fname);
   // find type of package
 
   void openNetFiles(QStringList urls, bool install=TRUE);
@@ -95,6 +104,8 @@ public:
   static QString getFileName(const KURL & url, QString &cacheName);
   // return file name, if not local file cachename is name for cache entry
 
+  static bool isFileLocal( const KURL & url );
+  // true if URL refers to local or cached file
 
 protected:
   void resizeEvent(QResizeEvent *re);
@@ -120,11 +131,11 @@ private:
   // This arranges the widgets in the window (should be called after a
   // resize event)
 
-  KFileDialog* getFileDialog(QString captiontext);
+  KFileDialog* getFileDialog(const QString &captiontext);
 
   ///////////// SLOTS --------------------------------------------------------
 public slots:
-    
+
 //  void modeFinished(int mode, pkgInterface *interface, int refresh);
   // This is called when the mode `mode' has finished.  KPACKAGE should
   // then change modes appropriately
@@ -135,6 +146,9 @@ public slots:
   void clearMarked();
   // clear package Marks
 
+  void markAll();
+  // mark all packages in the selected view
+
   void expandTree();
   void collapseTree();
   // expand and collapse file tree
@@ -159,7 +173,7 @@ public slots:
   ///////////// DATA ---------------------------------------------------------
 public:
 
-  enum { Management, Installation } ; 
+  enum { Management, Installation } ;
   // Widget modes
 
   KConfig *config;
@@ -177,7 +191,7 @@ private:
 
   // Menu item identifiers
 
-  QFrame *statusbar;	    
+  QFrame *statusbar;
   // the status bar
 
   KProgress *processProgress;
@@ -218,10 +232,7 @@ public:
   KPKG(KConfig *_config);
   // Constructor
 
-  ~KPKG();
-  // Destructor
-
-  void add_recent_file(QString newfile);
+  void add_recent_file(const QString &newfile);
   // keep list of files accessed
 
   void writeSettings();
@@ -232,7 +243,7 @@ public:
   // save and read restart sstate
 
   void disableMenu();
-  void enableMenu();	
+  void enableMenu();
   // enable/deisable menu elements
 
   bool prop_restart;
@@ -244,15 +255,13 @@ public:
   KConfig *config ;
   // Saved config information
 
-  KAccel *keys;
-
   void disableNext();
   void enableNext();
   void disablePrevious();
   void enablePrevious();
   // Control next and previous commands
 
- 
+
 private:
 
   void setupMenu();
@@ -268,7 +277,6 @@ private:
   KAction *pack_next;
   KAction *pack_install;
   KAction *pack_uninstall;
-  KToggleAction *pack_toolbar;
 
   int  toolID, selectID;
   // refrences to  toolbar  and menu items
@@ -285,14 +293,9 @@ public slots:
 
   void setOptions();
   // set options
-  
-  void setKeys();
-  
+
   void saveSettings();
   // save config
-  
-  void toggleToolBar();
-  // toggle existance of tool bar
 
   void configureToolBars();
 
@@ -302,8 +305,11 @@ public slots:
   void clearDCache();
   // Clear directory cache
 
+private slots:
+  void slotNewToolbarConfig();
+
 protected:
-    void closeEvent ( QCloseEvent *e);
+  void closeEvent ( QCloseEvent *e);
 };
 
 //////////////////////////////////////////////////////////////////////////////
@@ -322,5 +328,3 @@ void KpMsg(QString lab, QString msg, bool stop);
 void KpMsgE(QString msg, bool stop = FALSE);
 #endif
 
-
-
