@@ -53,9 +53,10 @@
 #include "slackInterface.h"
 #include "fbsdInterface.h"
 #include "rpmInterface.h"
+#include "gentooInterface.h"
 
 
-static const char *description = 
+static const char description[] =
 	I18N_NOOP("KDE Package installer");
 
 static KCmdLineOptions options[] =
@@ -120,6 +121,7 @@ int main(int argc, char **argv)
   kpinterface[j++] = new RPM();
   kpinterface[j++] = new fbsdInterface();
   kpinterface[j++] = new SLACK(); // Also catched BSD packages...
+  kpinterface[j++] = new Gentoo();
   
   opts->readLaterSettings();
 
