@@ -1,9 +1,7 @@
-/////////////////////////////////////////////////////////////////////////
-// $Id: packageDisplay.h,v 1.9 2002/04/22 18:48:35 arbab Exp $	
-// File  : packageDisplay.h
-// Author: Damyan Pepper
-// Author: Toivo Pedaste
-//
+/* packageDisplay.h
+**
+** Copyright (C) 1999,2000 Toivo Pedaste <toivo@ucs.uwa.edu.au>
+**
 // This widget is used to display information and the file list of a
 // package.
 //
@@ -14,10 +12,31 @@
 //
 // The widget is mainly a QTabDialog with two tabs: Info and FileList.
 // The Info tab is the default one.
-//
-// It may prove that the tab dialog idea doesn't work. Something else
-// will have to be done in that case!!!
-/////////////////////////////////////////////////////////////////////////
+*/
+
+/*
+** This program is free software; you can redistribute it and/or modify
+** it under the terms of the GNU General Public License as published by
+** the Free Software Foundation; either version 2 of the License, or
+** (at your option) any later version.
+**
+** This program is distributed in the hope that it will be useful,
+** but WITHOUT ANY WARRANTY; without even the implied warranty of
+** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+** GNU General Public License for more details.
+**
+** You should have received a copy of the GNU General Public License
+** along with this program in a file called COPYING; if not, write to
+** the Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
+** MA 02111-1307, USA.
+*/
+
+/*
+** Bug reports and questions can be sent to kde-devel@kde.org
+*/
+
+
+
 
 #ifndef PACKAGEDISPLAY_H
 #define PACKAGEDISPLAY_H
@@ -34,6 +53,7 @@ class packagePropertiesWidget;
 class packageInfo;
 class KListView;
 class QListViewItem;
+class QTextEdit;
 
 class packageDisplayWidget : public QTabWidget
 {
@@ -50,6 +70,9 @@ public:
   void noPackage();
   // clear package display in right panel
 
+  void changePackage(packageInfo *p);
+  // Set currently selected package
+
 private:
   void setupWidgets();
   // This sets up the sub-widgets
@@ -58,29 +81,43 @@ private:
   // This updates the file list to match that found with the currently
   // selected package
   
+  void updateChangeLog();
+  // This updates the change log to match that found with the currently
+  // selected package
+  
+  void tabSet(QWidget *);
+  // Set display for corresponding tab
+
   ///////////// SLOTS --------------------------------------------------------
 public slots:
-  void changePackage(packageInfo *p);
 
-  void tabSelected(const QString &);
+  void tabSelected(QWidget *);
 
   void openBinding(QListViewItem *);
 
   ///////////// SIGNALS ------------------------------------------------------
 
   ///////////// DATA ---------------------------------------------------------
-private:
+public:
   packageInfo *package;
   // the currently selected package
 
+private:
+
   QTabWidget *tabbar;
   // The tab bar
 
-  QVBox *proptab, *fltab;
+  QVBox *proptab, *fltab, *cltab;
+
+  QWidget *curTab;
+  // current active tab
 
   KListView *fileList;
   // This holds the file list (and is used as a page on the tab dialog)
 
+  QTextEdit *changeLog;
+  // Holds changelog
+
   QPixmap tick, cross, question, *blank;
   // The pixmaps for the filelist
 
