@@ -1,21 +1,49 @@
-
-///////////////////////////////////////////////////////////////////////////////
-// $Id: packageInfo.cpp,v 1.29.4.1 2002/12/13 15:20:22 toivo Exp $
-// File  : packageInfo.cpp
+/* packageInfo.cpp
+**
+** Copyright (C) 1999,2000 Toivo Pedaste <toivo@ucs.uwa.edu.au>
+**
 // Author: Damyan Pepper
 // Author: Toivo Pedaste
-//
-///////////////////////////////////////////////////////////////////////////////
+*/
+
+/*
+** This program is free software; you can redistribute it and/or modify
+** it under the terms of the GNU General Public License as published by
+** the Free Software Foundation; either version 2 of the License, or
+** (at your option) any later version.
+**
+** This program is distributed in the hope that it will be useful,
+** but WITHOUT ANY WARRANTY; without even the implied warranty of
+** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+** GNU General Public License for more details.
+**
+** You should have received a copy of the GNU General Public License
+** along with this program in a file called COPYING; if not, write to
+** the Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
+** MA 02111-1307, USA.
+*/
+
+/*
+** Bug reports and questions can be sent to kde-devel@kde.org
+*/
+
+
+
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
 
-#include "../config.h"
 // Standard headers
 #include <stdlib.h>
 
 #include <qregexp.h>
 #include <qdir.h>
+#include <ctype.h>
 
 // KDE headers
 #include <kglobal.h>
+#include <klocale.h>
+#include <kdebug.h>
 
 // kpackage headers
 #include "kpackage.h"
@@ -25,8 +53,6 @@
 #include "managementWidget.h"
 #include "utils.h"
 #include "options.h"
-#include <klocale.h>
-#include <ctype.h>
 
 // Global pixmap for
 QPixmap *pict = NULL;
@@ -86,18 +112,19 @@ QDict<QString> *packageInfo::getDict()
 // Initialize fields if missing
 void packageInfo::fixup()
 {
+  if (!info->find("name")) {
+    QString *q = new QString();
+    q->setNum((int)this);
+    info->insert("name", q);
+  }
+
   if (!info->find("group")) {
     info->insert("group", new QString(i18n("OTHER")));
+    kdDebug() << "Package " << *(info->find("name")) << " has no group set." << endl;
   }
 
   if (!info->find("version")) {
-    info->insert("version", new QString(""));
-  }
-
-  if (!info->find("name")) {
-    QString *q = new QString("");;
-    q->setNum((int)this);
-    info->insert("name", q);
+    info->insert("version", new QString());
   }
 }
 
@@ -135,6 +162,32 @@ QString packageInfo::fetchFilename()
   }
 }
 
+bool packageInfo::isFileLocal()
+{
+  QString aurl = getUrl();
+  if (!aurl.isEmpty()) {
+    return KPACKAGE::isFileLocal(aurl);
+  } 
+  return false;
+}
+
+bool packageInfo::isInstallable()
+{
+  if (packageState != packageInfo::INSTALLED &&
+      !getProperty("filename").isNull() ) 
+    return true;
+  else
+    return false;
+}
+
+bool packageInfo::isFetchable()
+{
+  if (interface->noFetch || !getFilename().isEmpty() ) 
+    return true;
+  else
+    return false;
+}
+
 QString packageInfo::getFilename()
 {
   QString cn = "";
@@ -235,11 +288,11 @@ int packageInfo::pnewer(QString s, QString sp)
     QString svs = getNdigElement(s,&ns);
     QString svsp = getNdigElement(sp,&nsp);
     //    kdDebug() << "vs=" << ns << " " << svs << " sp=" << nsp << " " << svsp << "\n";
-    if (svs == "" && svsp == "")
+    if (svs.isEmpty() && svsp.isEmpty())
       return 0;
-    if (svs == "" && svsp != "")
+    if (svs.isEmpty() && !svsp.isEmpty())
       return 1;
-    if (svs != "" && svsp == "")
+    if (!svs.isEmpty() && svsp.isEmpty())
       return -1;
 
     if (svsp.isNull()) { // Allow for QT strangeness comparing null string
@@ -369,9 +422,9 @@ KPLVItem *packageInfo::place(KPQListView *tree, bool insertI)
 	search = group->firstChild();
       } else {
 	if (parent) {
-	  group = new KPLVItem(parent, this, interface->folder, *it);
+	  group = new KPLVItem(parent, 0, interface->folder, *it);
 	} else {
-	  group = new KPLVItem(tree, this, interface->folder, *it);
+	  group = new KPLVItem(tree, 0, interface->folder, *it);
 	}
 	parent = group;
 	parent->setOpen(TRUE);
