@@ -1,8 +1,8 @@
-//////////////////////////////////////////////////////////////////////////
-// 	$Id: packageInfo.h,v 1.13 2001/09/26 16:33:31 mlaurent Exp $	
-// File  : packageInfo.h
+/* packageInfo.h
+**
+** Copyright (C) 1999,2000 Toivo Pedaste <toivo@ucs.uwa.edu.au>
+**
 // Author: Damyan Pepper
-// Author: Toivo Pedaste
 //
 // This file contains the definition of the class packageInfo
 //
@@ -19,7 +19,28 @@
 // a tree list with the function `place'.  Doing this creates
 // a tree list item object that can be accessed with the function
 // `item'.
-//////////////////////////////////////////////////////////////////////////
+*/
+
+/*
+** This program is free software; you can redistribute it and/or modify
+** it under the terms of the GNU General Public License as published by
+** the Free Software Foundation; either version 2 of the License, or
+** (at your option) any later version.
+**
+** This program is distributed in the hope that it will be useful,
+** but WITHOUT ANY WARRANTY; without even the implied warranty of
+** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+** GNU General Public License for more details.
+**
+** You should have received a copy of the GNU General Public License
+** along with this program in a file called COPYING; if not, write to
+** the Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
+** MA 02111-1307, USA.
+*/
+
+/*
+** Bug reports and questions can be sent to kde-devel@kde.org
+*/
 
 #ifndef PACKAGEINFO_H
 #define PACKAGEINFO_H
@@ -77,7 +98,19 @@ public:
   // returns the property dictionary for the package
 
   void setFilename(QString f);
+
   QString getUrl();
+  // return URL of package file
+
+  bool isFileLocal();
+  // True if package file is local or cached file
+
+  bool isInstallable();
+  // True if package can be installed
+
+  bool isFetchable();
+  // True if package needs to be fetched
+
   QString getFilename();
 
   QString fetchFilename();
