@@ -131,7 +131,7 @@ void packagePropertiesWidget::changePackage(packageInfo *p)
     }
 
     stmp = "";
-    stmp += "<HTML><HEAD></HEAD><BODY  TEXT=\"#000000\" BGCOLOR=\"#ffffff\"><H1>";
+    stmp += "<HTML><HEAD></HEAD><BODY><H1>";
     stmp += "<b><font face=\"Times New Roman,Times\">";
     stmp += p->getProperty("name");
     stmp += "</font></b></H1><HR>";
