@@ -1,24 +1,35 @@
-//////////////////////////////////////////////////////////////
-// 	$Id: rpmInterface.h,v 1.21.2.1 2002/12/13 15:20:22 toivo Exp $
-//
-// Author: Toivo Pedaste
-//
-//////////////////////////////////////////////////////////////
+/* rpmInterface.h
+**
+** Copyright (C) 1999,2000 Toivo Pedaste <toivo@ucs.uwa.edu.au>
+**
+*/
+
+/*
+** This program is free software; you can redistribute it and/or modify
+** it under the terms of the GNU General Public License as published by
+** the Free Software Foundation; either version 2 of the License, or
+** (at your option) any later version.
+**
+** This program is distributed in the hope that it will be useful,
+** but WITHOUT ANY WARRANTY; without even the implied warranty of
+** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+** GNU General Public License for more details.
+**
+** You should have received a copy of the GNU General Public License
+** along with this program in a file called COPYING; if not, write to
+** the Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
+** MA 02111-1307, USA.
+*/
+
+/*
+** Bug reports and questions can be sent to kde-devel@kde.org
+*/
 
 #ifndef RPM_IFACE_H
 #define RPM_IFACE_H
 
 #include "../config.h"
 
-#ifdef HAVE_RPM
-#include <sys/types.h>
-/* stupid RPM headers! */
-typedef __off64_t off64_t;
-#include <rpm/rpmlib.h>
-#else
-  typedef struct  Header{
-};
-#endif
 
 #include <qptrlist.h>
 
@@ -40,6 +51,14 @@ public:
 
   packageInfo *getPackageInfo(char mode, const QString &name, const QString &version);
   QStringList getFileList(packageInfo *p);
+  QStringList getChangeLog(packageInfo *p);
+
+  bool filesTab(packageInfo *p);
+  // If files tab is to be enabled
+
+  bool changeTab(packageInfo *p);
+  // If change log tab is to be enabled
+
   QStringList depends(const QString &name, int src);
   QStringList verify(packageInfo *p, const QStringList &files);
 
@@ -64,29 +83,26 @@ public slots:
   void setAvail(LcacheObj *);
 
 private:
-#ifdef HAVE_RPM
-  packageInfo* collectInfo(Header h);
-#else
   packageInfo* collectInfo(QStringList &ln);
-#endif
-  QStringList collectFileList(Header h);
+
   void listInstalledPackages(QPtrList<packageInfo> *pki);
 
   QDict<QString> provides;
   bool rpmSetup;
   QStringList infoList;
 
-#ifndef HAVE_RPM
   QString packageQuery();
   
   QStringList getIFileList(packageInfo *p);
   QStringList getUFileList(QString fn);
 
+  QStringList getIChangeLog(packageInfo *p);
+  QStringList getUChangeLog(QString fn);
+
   packageInfo *getIPackageInfo( QString name);
   packageInfo *getUPackageInfo( QString name);
 
   QString quotePath( QString path);
-#endif
 
  };
 
