@@ -79,7 +79,7 @@ SLACK::SLACK():pkgInterface()
   locatedialog = 0;
 
   queryMsg = i18n("Querying SLACK package list: ");
-  procMsg = i18n("Kpackage: Waiting on SLACK");
+  procMsg = i18n("KPackage: Waiting on SLACK");
 
   locatedialog = new Locations(i18n("Location of Slackware Package Archives"));
   locatedialog->pLocations(1, 1, this,  i18n("Install location", "I"),
