@@ -17,7 +17,7 @@
 #ifndef KSV_ACTIONLIST_H
 #define KSV_ACTIONLIST_H
 
-#include <qstack.h>
+#include <qptrstack.h>
 #include <qobject.h>
 
 class KSVData;
@@ -105,7 +105,7 @@ private:
 
 
 
-class ActionList : public QObject, private QStack<KSVAction>
+class ActionList : public QObject, private QPtrStack<KSVAction>
 {
   Q_OBJECT
   
@@ -113,7 +113,7 @@ public:
   ActionList (QObject* parent, const char* name);
   virtual ~ActionList ();
 
-  KSVAction* top () const { return QStack<KSVAction>::top(); }
+  KSVAction* top () const { return QPtrStack<KSVAction>::top(); }
 
 public slots:
   void undoLast ();
