@@ -19,7 +19,7 @@
 
 #include <qtooltip.h>
 
-class K2ListView;
+class KSVDragList;
 
 /**
   * @short custom tooltip for use in @ref KDragList
@@ -28,7 +28,7 @@ class K2ListView;
 class KDLToolTip : public QToolTip
 {
 public:
-  KDLToolTip (K2ListView *parent, QToolTipGroup* group = 0L);
+  KDLToolTip (KSVDragList *parent, QToolTipGroup* group = 0L);
   virtual ~KDLToolTip();
 
 protected:
@@ -38,7 +38,7 @@ protected:
   virtual void maybeTip (const QPoint&);
 
 private:
-  K2ListView* mParent;
+  KSVDragList* mParent;
 };
 
 #endif
