@@ -23,9 +23,13 @@ public:
   void setServiceFont (const QFont& font);
   void setNumberFont (const QFont& font);
 
+signals:
+  void configChanged();
+
 protected slots:
   void chooseServiceFont();
   void chooseNumberFont();
+  void slotChanged();
 
 private:
   QFont mServiceFont;
