@@ -18,8 +18,6 @@
 
 #include <iostream>
 
-#include <qvariant.h>
-
 #include <kcmdlineargs.h>
 #include <kaboutdata.h>
 #include <kglobal.h>
@@ -27,19 +25,13 @@
 #include <kstandarddirs.h>
 
 #include "ksvapplication.h"
-#include "ksv_core.h"
 #include "ksv_conf.h"
 #include "ksvconfigwizard.h"
 #include "TopWidget.h"
-
-// copyright notice
 #include "version.h"
 
 using namespace std;
 
-static const char copyright[] = "SysV-Init Editor " KSYSV_VERSION_STRING " Copyright  1997-2000 Peter Putzer.";
-static const char license []  = "All rights reserved. Released under the GNU General Public License (GPL).";
-
 #if (defined(DEBUG) && !(defined(NDEBUG) || defined(NO_DEBUG)))
 #define KSYSV_DEBUG(x)  x
 #else
@@ -65,16 +57,13 @@ int main( int argc, char **argv ) {
   // install own message handler that ignores debug-msg when DEBUG is not defined
   qInstallMsgHandler(myMessageOutput);
 
-  cout << copyright << endl << license << endl << endl;
-
   KAboutData about("ksysv", I18N_NOOP("SysV-Init Editor"), KSYSV_VERSION_STRING,
-				   I18N_NOOP ("An editor for Sys-V like init configurations."),
+				   I18N_NOOP ("Editor for Sys-V like init configurations"),
 				   KAboutData::License_GPL,
-				   "Copyright  1997-2000, Peter Putzer.",
-				   I18N_NOOP ("An editor for SysV-style init configuration, similar to Red Hat's\n" \
-                              "\"tksysv\", but SysV-Init Editor allows drag-and-drop, as well as\n" \
-                              "keyboard use."),
-				   "http://eclipt.uni-klu.ac.at/projects/ksysv");
+				   "Copyright (c) 1997-2000, Peter Putzer.",
+				   I18N_NOOP ("Similar to Red Hat's" \
+                              "\"tksysv\", but SysV-Init Editor allows\n" \
+			      "drag-and-drop, as well as keyboard use."));
   about.addAuthor ("Peter Putzer", I18N_NOOP("Main developer"), "putzer@kde.org");
   ksv::about = &about;
 
@@ -82,18 +71,15 @@ int main( int argc, char **argv ) {
   KUniqueApplication::addCmdLineOptions ();
 
   if (!KUniqueApplication::start()) {
-	cerr << "SysV-Init Editor is already running!" << endl;
+    cerr << "SysV-Init Editor is already running!" << endl;
     return -1;
   }
 
   KSVApplication app;
 
-  // to signal errors to scripts... well its cleaner at least
-  int returnValue = 1;
-
   // session-management
   if (kapp->isRestored())
-	RESTORE(KSVTopLevel)
+    RESTORE(KSVTopLevel)
   else
     {
       KSVConfig* conf = KSVConfig::self();
@@ -113,7 +99,6 @@ int main( int argc, char **argv ) {
     }
   // end session-management
 
-  returnValue = app.exec();
-
-  return -returnValue;
+  return app.exec();
 }
+
