@@ -1,5 +1,6 @@
 /*
  *  Copyright (c) 1998 Denis Perchine <dyp@perchine.com>
+ *  Copyright (c) 2004 Szombathelyi György <gyurco@freemail.hu>
  *  Maintained by Adriaan de Groot <groot@kde.org>
  *
  *  This program is free software; you can redistribute it and/or
@@ -20,41 +21,35 @@
 #ifndef _KU_MAINWIDGET_H
 #define _KU_MAINWIDGET_H
 
-#include <qevent.h>
-#include <qpixmap.h>
-
 #include <kmainwindow.h>
-#include <kaction.h>
-#include <kstatusbar.h>
 
-#include "mainView.h"
+class SelectConn;
+class mainView;
+class KToggleAction;
 
 class mainWidget : public KMainWindow {
 Q_OBJECT
 public:
   mainWidget(const char *name = 0);
   ~mainWidget();
-
   bool queryClose();
 
 protected:
-  virtual void resizeEvent (QResizeEvent *event);
-  
+  void init();
   void setupActions();
-  void readSettings();
-  void writeSettings();
 
 protected slots:
-  void toggleToolBar();
-  void toggleStatusBar();
+  void showSys();
+  void properties();
+  void slotApplySettings();
+  void slotApplyConnection();
+  void selectconn();
 
 private:
-//  KMenuBar   *menubar;
-//  KToolBar   *toolbar;
-  KStatusBar *sbar;
-  KToggleAction *mActionToolbar;
-  KToggleAction *mActionStatusbar;
+  KToggleAction *mShowSys;
   mainView *md;
+  SelectConn *sc;
+
 };
 
 #endif // _KU_MAINWIDGET_H
