@@ -1,6 +1,7 @@
 /*
  *  Copyright (c) 1998 Denis Perchine <dyp@perchine.com>
- *  Maintained by Adriaan de Groot <groot@kde.org>
+ *  Copyright (c) 2004 Szombathelyi György <gyurco@freemail.hu>
+ *  Former maintainer: Adriaan de Groot <groot@kde.org>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU General Public
@@ -21,22 +22,12 @@
 
 #include <stdio.h>
 #include <stdlib.h>
-#include <time.h>
+#ifdef HAVE_UNISTD_H
 #include <unistd.h>
-
-#ifdef HAVE_MNTENT_H
-#include <mntent.h>
 #endif
-
-#ifdef HAVE_SYS_MNTENT_H
-#include <sys/mntent.h>
-#define BAD_GETMNTENT
+#ifdef HAVE_CRYPT_H
+#include <crypt.h>
 #endif
-
-#ifdef HAVE_SYS_MNTTAB_H
-#include <sys/mnttab.h>
-#endif
-
 #include <qfile.h>
 
 #include <kmessagebox.h>
@@ -44,96 +35,50 @@
 #include "misc.h"
 #include "kglobal_.h"
 
-void backup(const QString & name)
+bool backup(const QString & name)
 {
   QString tmp = name + QString::fromLatin1(KU_BACKUP_EXT);
   unlink(QFile::encodeName(tmp));
 
-  if (rename(QFile::encodeName(name), QFile::encodeName(tmp)) == -1)
+  if (copyFile(QFile::encodeName(name), QFile::encodeName(tmp)) == -1)
   {
     QString str;
-    str = i18n("Can't create backup file for %1").arg(name);
-    KMessageBox::error(0, tmp);
-    exit (1);
+    KMessageBox::error( 0, i18n("Can't create backup file for %1").arg(name) );
+    return false;
   }
+  return true;
 }
 
-long today() {
-  return (time(NULL)/(24*60*60));
-}
-
-char *updateString(char *d, const char *t) {
-  free(d);
-  d = (char *)malloc(strlen(t)+1);  
-  strcpy(d,t);
-  return d;
-}
-
-int getValue(long int &data, const QString & text, const QString & msg) {
-  bool ok;
-  long int value = text.toLong(&ok);
-  if (!ok) {
-    KMessageBox::error(0, msg);
-    return (-1);
-  }
-  data = value;
-
-  return (0);
-}
-
-int getValue(int &data, const QString & text, const QString & msg) {
-  bool ok;
-  long int value = text.toLong(&ok);
-  if (!ok) {
-    KMessageBox::error(0, msg);
-    return (-1);
-  }
-  data = value;
-
-  return (0);
-}
-
-int getValue(unsigned int &data, const QString & text, const QString & msg) {
-  bool ok;
-  long int value = text.toLong(&ok);
-  if (!ok) {
-    KMessageBox::error(0, msg);
-    return (-1);
-  }
-  data = value;
-
-  return (0);
+time_t now() {
+  struct timeval tv;
+  
+  gettimeofday( &tv, NULL );
+  return ( tv.tv_sec );
 }
 
 #define BLOCK_SIZE 65536
 
-int copyFile(const QString & from, const QString & to) {
+int copyFile(const QString & from, const QString & to) 
+{
   QFile fi;
   QFile fo;
   char buf[BLOCK_SIZE];
 
-#ifdef _KU_DEBUG
-  printf("%s -> %s\n", from.local8Bit().data(), to.local8Bit().data());
-#endif
-  
   fi.setName(from);
   fo.setName(to);
   
   if (!fi.exists()) {
-    err->addMsg(i18n("File %1 does not exist.").arg(from));
-		err->display(); 
+    KMessageBox::error( 0, i18n("File %1 does not exist.").arg(from) );
     return (-1);
   }
 
   if (!fi.open(IO_ReadOnly)) {
-    err->addMsg(i18n("Cannot open file %1 for reading.").arg(from));
-		err->display();
+    KMessageBox::error( 0, i18n("Cannot open file %1 for reading.").arg(from) );
     return (-1);
   }
 
   if (!fo.open(IO_Raw | IO_WriteOnly | IO_Truncate)) {
-    err->addMsg(i18n("Cannot open file %1 for writing.").arg(to));
-		err->display();
+    KMessageBox::error( 0, i18n("Cannot open file %1 for writing.").arg(to) );
     return (-1);
   }
   
@@ -186,3 +131,42 @@ void addShell(const QString &shell)
     }
     fclose(f);
 }
+
+QCString genSalt( int len )
+{
+  QCString salt( len + 1 );
+  const char * set = "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789./";
+    
+  salt[0] = set[getpid() % strlen(set)];
+  for( int i = 1; i < len; i++ ) {
+    salt[i] = set[kapp->random() % strlen(set)];
+  }
+  return salt;
+}
+
+QString encryptPass( const QString &pass, bool md5 )
+{
+  QCString salt;
+  char tmp[128];
+  
+  if ( md5 ) {
+    salt = "$1$";
+    salt += genSalt( 8 );
+    salt += '$';
+  
+  } else {
+    salt = genSalt( 2 );
+  }
+  strcpy( tmp, crypt( QFile::encodeName( pass ), salt ) );
+  return QString::fromLocal8Bit( tmp );
+}
+
+int timeToDays(time_t time)
+{
+  return time < 0 ? -1 : time/(24*60*60);
+}
+
+time_t daysToTime(int days)
+{
+  return days*24*60*60;
+}
